==> aria2_1.10.9.orig.tar.bz2: aria2-1.10.9/src/BtCancelSendingPieceEvent.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_BT_CANCEL_SENDING_PIECE_EVENT_H
#define D_BT_CANCEL_SENDING_PIECE_EVENT_H

#include "common.h"

namespace aria2 {

class BtCancelSendingPieceEvent {
private:
  size_t index_;
  uint32_t begin_;
  size_t length_;
public:
  BtCancelSendingPieceEvent(size_t index, uint32_t begin, size_t length):
    index_(index), begin_(begin), length_(length) {}

  size_t getIndex() const { return index_; }

  uint32_t getBegin() const { return begin_; }

  size_t getLength() const { return length_; }
};

} // namespace aria2

#endif // D_BT_CANCEL_SENDING_PIECE_EVENT_H

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/BtCancelSendingPieceEvent.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_BT_CANCEL_SENDING_PIECE_EVENT_H
#define D_BT_CANCEL_SENDING_PIECE_EVENT_H

#include "common.h"

namespace aria2 {

class BtCancelSendingPieceEvent {
private:
  size_t index_;
  int32_t begin_;
  int32_t length_;
public:
  BtCancelSendingPieceEvent(size_t index, int32_t begin, int32_t length):
    index_(index), begin_(begin), length_(length) {}

  size_t getIndex() const { return index_; }

  int32_t getBegin() const { return begin_; }

  int32_t getLength() const { return length_; }
};

} // namespace aria2

#endif // D_BT_CANCEL_SENDING_PIECE_EVENT_H
